konserve-dynamodb.layout

Physical layout for logical Konserve blobs. Fragments are immutable and never enumerated as logical keys. Old generations are retained for existing readers.

Physical layout for logical Konserve blobs. Fragments are immutable and never
enumerated as logical keys. Old generations are retained for existing readers.
raw docstring

binary-attrclj

(binary-attr x)
source

bytes-ofclj

(bytes-of x)
source

digestclj

(digest x)
source

format-nameclj

source

fragment-keyclj

(fragment-key generation i)
source

fragment-key?clj

(fragment-key? key)
source

fragment-prefixclj

source

fragment-sizeclj

source

inline-itemclj

(inline-item key {:keys [header meta value]})
source

item-limitclj

source

item-sizeclj

(item-size item)

Exact size for the String/Binary attributes emitted by this layout. Manifest numeric fields are strings too, so no DynamoDB number-size estimate is needed.

Exact size for the String/Binary attributes emitted by this layout. Manifest
numeric fields are strings too, so no DynamoDB number-size estimate is needed.
sourceraw docstring

manifestclj

(manifest item)
source

packclj

(pack {:keys [header meta value]})
source

planclj

(plan key data inline-budget)
(plan key data inline-budget overflow-write?)

Plan a write without I/O. A batch can lower inline-budget so its published items fit in one transaction even when all original values fit individually.

Plan a write without I/O. A batch can lower inline-budget so its published
items fit in one transaction even when all original values fit individually.
sourceraw docstring

string-attrclj

(string-attr x)
source

string-ofclj

(string-of x)
source

transaction-limitclj

source

unpackclj

(unpack payload)
source

cljdoc builds & hosts documentation for Clojure/Script libraries