Physical layout for logical Konserve blobs. Fragments are immutable and never enumerated as logical keys. Old generations are retained for existing readers.
Physical layout for logical Konserve blobs. Fragments are immutable and never enumerated as logical keys. Old generations are retained for existing readers.
(item-size item)Exact size for the String/Binary attributes emitted by this layout. Manifest numeric fields are strings too, so no DynamoDB number-size estimate is needed.
Exact size for the String/Binary attributes emitted by this layout. Manifest numeric fields are strings too, so no DynamoDB number-size estimate is needed.
(plan key data inline-budget)(plan key data inline-budget overflow-write?)Plan a write without I/O. A batch can lower inline-budget so its published items fit in one transaction even when all original values fit individually.
Plan a write without I/O. A batch can lower inline-budget so its published items fit in one transaction even when all original values fit individually.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |